<xsl:stylesheet version="1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:import href="table.db-fo.xsl"/>
  <xsl:output method="xml" indent="no"/>
  <xsl:strip-space elements="paper front author address bio abstract keywords body section subsec1 subsec2 subsec3 rear acknowl bibliog bibitem lquote note figure caption randlist seqlist li deflist def.item def acronym.grp ftnote table thead tgroup row">
  <xsl:variable name="secnumbers" select="paper/@secnumbers"/>
  <xsl:variable name="footnotes" select="//ftnote"/>
  <xsl:variable name="authors" select="/paper/front/author"/>
  <xsl:variable name="rootdir" select="'../../..'"/>
  <xsl:variable name="bodymargin" select="'1in'"/>
  <xsl:variable name="startmargin" select="'0.25in'"/>
  <xsl:variable name="headeroffset" select="'0.25in'"/>
  <xsl:variable name="mainfontsize" select="'10pt'"/>
  <xsl:variable name="mainlineheight" select="'12pt'"/>
  <xsl:variable name="smallfontsize" select="'9pt'"/>
  <xsl:variable name="smalllineheight" select="'11.5pt'"/>
  <xsl:variable name="mainindent" select="'15pt'"/>
  <xsl:variable name="sectiontopspace" select="'15pt'"/>
  <xsl:variable name="listtopspace" select="'12pt'"/>
  <xsl:variable name="extraindent" select="'24pt'"/>
  <xsl:variable name="hangingindent" select="concat('-', $mainindent)"/>
  <xsl:variable name="defoffset" select="'1.5in'"/>
  <xsl:variable name="blockbgcolor" select="'#EEDD82'"/>
  <xsl:variable name="mainbgcolor" select="'#FFFFFF'"/>
  <xsl:variable name="specialfacecolor" select="'#883300'"/>
  <xsl:variable name="extremelogo" select="concat($rootdir,'/icons/ex02.jpg')"/>
  <xsl:variable name="conference">
    <xsl:choose>
      <xsl:when test="/paper/front/conference">
        <xsl:value-of select="/paper/front/conference"/>
      </xsl:when>
      <xsl:otherwise>Extreme Markup Languages&reg;</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="venue">
    <xsl:choose>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages')">Montr&#xE9;al, Qu&#xE9;bec</xsl:when>
      <xsl:otherwise/>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="dates">
    <xsl:choose>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages 2002')">August 6-9, 2002</xsl:when>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages 2003')">August 4-8, 2003</xsl:when>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages 2004')">August 2-6, 2004</xsl:when>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages&reg; 2004')">August 2-6, 2004</xsl:when>
      <xsl:when test="contains(/paper/front/conference,'Extreme Markup Languages&lt;sup&gt;&reg;&lt;/sup&gt; 2004')">August 2-6, 2004</xsl:when>
      <xsl:otherwise/>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="creditsblocks">
    <fo:block
    font-style="italic"
    font-size="85%">
    This paper was formatted from XML source via XSL
  </fo:block>
    <fo:block
    font-style="italic"
    font-size="85%">
    Mulberry Technologies, Inc., August 2004
  </fo:block>
  </xsl:variable>
  <xsl:template match="/">
    <fo:root>

<fo:layout-master-set>
  <fo:simple-page-master master-name="first"
     page-height="11in"
     page-width="8.5in"
     margin-top="0.5in"
     margin-bottom="0.5in"
     margin-left="0.5in"
     margin-right="0.5in">
    <fo:region-body region-name="main"
      display-align="center"
      margin-top="36pt"
      margin-bottom="0.75in"
      margin-left="{$bodymargin}"
      margin-right="{$bodymargin}"/>
    <fo:region-before
        extent="0.75in"/>
    <fo:region-after region-name="footer"
        extent="0.6in"/>
  </fo:simple-page-master>
  <fo:simple-page-master master-name="recto"
       page-height="11in"
       page-width="8.5in"
       margin-top="0.5in"
       margin-bottom="0.5in"
       margin-left="0.5in"
       margin-right="0.5in">
    <fo:region-body region-name="main"
       margin-top="48pt" margin-bottom="48pt"
       margin-left="{$bodymargin}"
       margin-right="{$bodymargin}"/>
    <fo:region-before region-name="rectoheader"
        extent="0.5in"/>
    <fo:region-after region-name="rectofooter"
        extent="24pt"/>
  </fo:simple-page-master>
  <fo:simple-page-master master-name="verso"
       page-height="11in"
       page-width="8.5in"
       margin-top="0.5in"
       margin-bottom="0.5in"
       margin-left="0.5in"
       margin-right="0.5in">
    <fo:region-body region-name="main"
       margin-top="48pt" margin-bottom="48pt"
       margin-left="{$bodymargin}"
       margin-right="{$bodymargin}"/>
    <fo:region-before region-name="versoheader"
        extent="0.5in"/>
    <fo:region-after region-name="versofooter"
        extent="24pt"/>
    </fo:simple-page-master>
    <fo:page-sequence-master master-name="title">
      <fo:repeatable-page-master-reference master-reference="first"/>
    </fo:page-sequence-master>
    <fo:page-sequence-master master-name="body">
      <fo:repeatable-page-master-alternatives>
        <fo:conditional-page-master-reference odd-or-even="odd"
          master-reference="recto"/>
        <fo:conditional-page-master-reference odd-or-even="even"
          master-reference="verso"/>
      </fo:repeatable-page-master-alternatives>
    </fo:page-sequence-master>
</fo:layout-master-set>

  <xsl:apply-templates/>

  </fo:root>
  </xsl:template>
  <xsl:template match="paper">
    <fo:page-sequence master-reference="title">
    <fo:static-content flow-name="footer">
      <fo:block
        display-align="after"
        text-align="center">
        <fo:external-graphic
          overflow="visible"
          content-width="75%"
          src="{$extremelogo}"/>
      </fo:block>
    </fo:static-content>
    <fo:flow flow-name="main"
        font-size="{$mainfontsize}"
        line-height="{$mainlineheight}"
        font-family="serif">
      <fo:block>
        <xsl:apply-templates select="front"/>
      </fo:block>
    </fo:flow>
  </fo:page-sequence>
    <fo:page-sequence master-reference="body"
      initial-page-number="1">
    <fo:static-content flow-name="rectoheader">
      <fo:block text-align="end"
        font-size="10pt"
        font-family="sans-serif"
        font-style="italic"
        line-height="14pt" >
        <xsl:apply-templates select="/paper/front/title" mode="textonly"/>
      </fo:block>
    </fo:static-content>
    <fo:static-content flow-name="versoheader">
      <fo:block text-align="start"
        font-size="10pt"
        font-family="sans-serif"
        font-style="italic"
        line-height="14pt" >
        <xsl:apply-templates select="/paper/front/title" mode="textonly"/>
      </fo:block>
    </fo:static-content>
    <fo:static-content flow-name="rectofooter">
      <fo:block
        padding-before="6pt"  xsl:use-attribute-sets="borderbefore">
        <fo:list-block
          provisional-distance-between-starts="2.75in"
          provisional-label-separation="0pt">
          <fo:list-item>
            <fo:list-item-label end-indent="label-end()">
              <fo:block
                font-size="10pt"
                font-weight="bold">
                value-of $conference
              </fo:block>
            </fo:list-item-label>
            <fo:list-item-body
              start-indent="body-start()">
              <fo:block text-align="end"
                font-size="10pt">page <fo:page-number/></fo:block>
            </fo:list-item-body>
          </fo:list-item>
        </fo:list-block>
      </fo:block>
    </fo:static-content>
    <fo:static-content flow-name="versofooter">
      <fo:block
        padding-before="6pt"  xsl:use-attribute-sets="borderbefore">
        <fo:list-block
          provisional-distance-between-starts="4.75in"
          provisional-label-separation="0pt">
          <fo:list-item>
            <fo:list-item-label end-indent="label-end()">
              <fo:block
                font-size="10pt">page <fo:page-number/></fo:block>
            </fo:list-item-label>
            <fo:list-item-body
              start-indent="body-start()">
              <fo:block text-align="end"
                font-size="10pt"
                font-weight="bold">
                value-of $conference
              </fo:block>
            </fo:list-item-body>
          </fo:list-item>
        </fo:list-block>
      </fo:block>
    </fo:static-content>
    <fo:flow flow-name="main"
        font-size="{$mainfontsize}"
        line-height="{$mainlineheight}"
        font-family="serif">
      <fo:block><xsl:apply-templates select="body"/>
      <xsl:call-template name="footnotes"/>
      <xsl:call-template name="rear"/></fo:block>
    </fo:flow>
  </fo:page-sequence>
  </xsl:template>
  <xsl:attribute-set name="borderbefore">
    <xsl:attribute name="border-before-width">thin</xsl:attribute>
    <xsl:attribute name="border-before-style">solid</xsl:attribute>
    <xsl:attribute name="border-before-color">black</xsl:attribute>
  </xsl:attribute-set>
  <xsl:attribute-set name="borderafter">
    <xsl:attribute name="border-after-width">thin</xsl:attribute>
    <xsl:attribute name="border-after-style">solid</xsl:attribute>
    <xsl:attribute name="border-after-color">black</xsl:attribute>
  </xsl:attribute-set>
  <xsl:attribute-set name="boxborder">
    <xsl:attribute name="border-before-width">thin</xsl:attribute>
    <xsl:attribute name="border-before-style">solid</xsl:attribute>
    <xsl:attribute name="border-before-color">
      <xsl:value-of select="$specialfacecolor"/>
    </xsl:attribute>
    <xsl:attribute name="border-start-width">thin</xsl:attribute>
    <xsl:attribute name="border-start-style">solid</xsl:attribute>
    <xsl:attribute name="border-start-color">
      <xsl:value-of select="$specialfacecolor"/>
    </xsl:attribute>
    <xsl:attribute name="border-end-width">thin</xsl:attribute>
    <xsl:attribute name="border-end-style">solid</xsl:attribute>
    <xsl:attribute name="border-end-color">
      <xsl:value-of select="$specialfacecolor"/>
    </xsl:attribute>
    <xsl:attribute name="border-after-width">thin</xsl:attribute>
    <xsl:attribute name="border-after-style">solid</xsl:attribute>
    <xsl:attribute name="border-after-color">black</xsl:attribute>
  </xsl:attribute-set>
  <xsl:template match="ftnote" mode="textonly"/>
  <xsl:template match="front">
    <fo:block font-family="sans-serif">
    <xsl:call-template name="masthead"/>
    <fo:block  xsl:use-attribute-sets="headercontrol">
      <xsl:apply-templates select="title|subt" mode="titlepage"/>
    </fo:block><xsl:call-template name="authorblock"/>
      <xsl:apply-templates select="keywords"/>
      <xsl:apply-templates select="abstract"/>
      <xsl:call-template name="contents"/></fo:block>
  </xsl:template>
  <xsl:attribute-set name="borderafter">
    <xsl:attribute name="border-after-width">thin</xsl:attribute>
    <xsl:attribute name="border-after-style">solid</xsl:attribute>
    <xsl:attribute name="border-after-color">black</xsl:attribute>
  </xsl:attribute-set>
  <xsl:template match="front/title" mode="titlepage">
    <fo:block
    text-align="center"
    font-size="200%"
    line-height="120%"
    space-before="20pt">
    apply-templates
  </fo:block>
  </xsl:template>
  <xsl:template match="front/subt" mode="titlepage">
    <fo:block
    text-align="center"
    font-size="180%"
    font-style="italic"
    line-height="120%">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template name="authorblock">
    <fo:table
    space-before="15pt"
    padding-before="10pt"
    space-after="15pt"
    padding-after="10pt"
    font-size="10pt"
    line-height="11.5pt"
     xsl:use-attribute-sets="borderbefore borderafter">
    <fo:table-body><xsl:for-each select="author[boolean(position() mod 2)]">
        <fo:table-row>
          <fo:table-cell
            padding-before="3pt"
            padding-after="3pt"
            padding-end="0.25in"
            margin-left="0in"
            text-align="left"><xsl:if test="not(following-sibling::author[1])">
            <xsl:attribute name="number-columns-spanned">2</xsl:attribute>
          </xsl:if>
          <xsl:apply-templates select="." mode="titlepage"/></fo:table-cell>
          for-each following-sibling::author[1]
            <fo:table-cell
              padding-before="3pt"
              padding-after="3pt"
              padding-start="0.25in"
              margin-right="0in"
              text-align="right"><xsl:apply-templates select="." mode="titlepage"/></fo:table-cell>
        </fo:table-row>
      </xsl:for-each></fo:table-body>
  </fo:table>
  </xsl:template>
  <xsl:template match="author" mode="titlepage">
    <fo:block><xsl:apply-templates select="fname"/>&#160;<xsl:apply-templates select="surname"/></fo:block>
    <xsl:apply-templates select="address/affil" mode="titlepage"/>
  </xsl:template>
  <xsl:template match="affil" mode="titlepage">
    <fo:block font-style="italic">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="keywords"/>
  <xsl:template match="abstract">
    <fo:block
    space-before="{$sectiontopspace}"
    font-size="9pt"
    line-height="11.5pt"
    background-color="{$blockbgcolor}"
    padding-start="6pt"
    padding-end="6pt"
    padding-before="6pt"
    padding-after="6pt"
    margin-left="0.5in"
    margin-right="0.5in" >
    <fo:block
      keep-with-next="always"
      font-size="12pt"
      font-weight="bold"
      font-style="italic"
      space-after="6pt">Abstract</fo:block>
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template name="masthead">
    <fo:block
    background-color="{$blockbgcolor}"
    font-family="sans-serif">
    <fo:list-block
      provisional-distance-between-starts="3.75in"
      provisional-label-separation="9pt"
      margin-left="2pt"
      margin-right="6pt"
      margin-top="6pt"
      margin-bottom="6pt">
      <fo:list-item
        font-weight="bold">
        <fo:list-item-label
          end-indent="label-end()">
          <fo:block
            font-size="140%"
            line-height="120%"
            font-style="italic">
            <xsl:value-of select="$conference"/>
          </fo:block>
        </fo:list-item-label>
        <fo:list-item-body
          font-size="10pt"
          start-indent="body-start()">
          <fo:block text-align="end">
            <xsl:value-of select="$venue"/>
          </fo:block>
          <fo:block text-align="end">
            <xsl:value-of select="$dates"/>
          </fo:block>
        </fo:list-item-body>
      </fo:list-item>
    </fo:list-block>
  </fo:block>
  </xsl:template>
  <xsl:template name="contents">
    <fo:block
    keep-together.within-page="always"
    space-before.minimum="1in"
    font-size="10pt"
    font-family="serif"
    line-height="13pt"
    padding-before="6pt"
    padding-after="6pt" ><fo:block  xsl:use-attribute-sets="headercontrol">
      <xsl:apply-templates select="title|subt" mode="toc"/>
    </fo:block>
      <fo:block
      keep-with-next="always"
      font-family="sans-serif"
      font-size="12pt"
      font-weight="bold"
      font-style="italic"
      space-after="6pt">Table of Contents</fo:block>
      <xsl:apply-templates select="../body/section" mode="toc"/>
      <xsl:if test="$footnotes">
        <fo:block
        margin-left="{$mainindent}"
        text-indent="{concat('-', $mainindent)}"
        text-align-last="justify">
        Footnotes
        <fo:leader leader-pattern="dots"/>
        <fo:page-number-citation ref-id="footnotes"/>
      </fo:block>
      </xsl:if>
      <xsl:apply-templates select="../rear" mode="toc"/>
      <fo:block
      margin-left="{$mainindent}"
      text-indent="{concat('-', $mainindent)}"
      text-align-last="justify">
      The Author<xsl:if test="count($authors)>1">s</xsl:if>
      <fo:leader leader-pattern="dots"/>
      <fo:page-number-citation ref-id="authors"/>
    </fo:block></fo:block>
  </xsl:template>
  <xsl:template match="front/title" mode="toc">
    <fo:block
    font-size="160%"
    line-height="140%">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="front/subt" mode="toc">
    <fo:block
    font-size="140%"
    line-height="120%"
    font-style="italic">
    [apply-templates}
  </fo:block>
  </xsl:template>
  <xsl:template match="title" mode="toc">
    <xsl:if test="$secnumbers">
      <xsl:number level="multiple" format="1.1.1.1" count="section|subsec1|subsec2|subsec3"/>
      <xsl:text> </xsl:text>
    </xsl:if>
    <fo:basic-link internal-destination="{generate-id(..)}">
    <xsl:apply-templates mode="toc"/>
  </fo:basic-link>
    <fo:leader leader-pattern="dots"/>
    <fo:page-number-citation ref-id="{generate-id(..)}"/>
  </xsl:template>
  <xsl:template match="section|subsec1|subsec2|subsec3" mode="toc">
    <fo:block
    margin-left="{$mainindent}"
    text-indent="{concat('-', $mainindent)}"
    text-align-last="justify">
    <xsl:apply-templates select="title|subsec1|subsec2|subsec3" mode="toc"/>
  </fo:block>
  </xsl:template>
  <xsl:template match="fnref|ftnote|xref|bibref" mode="toc"/>
  <xsl:template match="acronym.grp" mode="toc">
    <xsl:apply-templates select="acronym"/>
  </xsl:template>
  <xsl:template match="*" mode="toc">
    <xsl:apply-templates select="."/>
  </xsl:template>
  <xsl:template match="rear" mode="toc">
    <xsl:apply-templates mode="toc"/>
  </xsl:template>
  <xsl:template match="acknowl" mode="toc">
    <fo:block
    margin-left="{$mainindent}"
    text-indent="{concat('-', $mainindent)}"
    text-align-last="justify">
    Acknowledgements
    <fo:leader leader-pattern="dots"/>
    <fo:page-number-citation ref-id="acknowl"/>
  </fo:block>
  </xsl:template>
  <xsl:template match="bibliog" mode="toc">
    <fo:block
    margin-left="{$mainindent}"
    text-indent="{concat('-', $mainindent)}"
    text-align-last="justify">
    Bibliography
    <fo:leader leader-pattern="dots"/>
    <fo:page-number-citation ref-id="bibliog"/>
  </fo:block>
  </xsl:template>
  <xsl:template match="body">
    <xsl:call-template name="bodyheader"/>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template name="bodyheader">
    <fo:block  xsl:use-attribute-sets="headercontrol">
    <xsl:apply-templates select="../front/title|../front/subt"/>
  </fo:block>
    <xsl:call-template name="authorline"/>
  </xsl:template>
  <xsl:template match="front/title">
    <fo:block
    id="{generate-id()}"
    font-size="200%"
    line-height="120%">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="front/subt">
    <fo:block
    id="{generate-id()}"
    font-size="160%"
    font-style="italic"
    line-height="120%">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template name="authorline">
    <fo:block
    font-family="sans-serif"
    font-size="120%"
    line-height="120%"
    font-style="italic"><xsl:for-each select="../front/author">
        <xsl:if test="not(position()=1) and not(position()=last() and position()=2)">,</xsl:if>
        <xsl:if test="not(position()=1) and position()=last()"> and</xsl:if>
        <xsl:if test="not(position()=1)">
          <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:apply-templates select="fname"/>&#160;<xsl:apply-templates select="surname"/>
      </xsl:for-each></fo:block>
  </xsl:template>
  <xsl:attribute-set name="headercontrol">
    <xsl:attribute name="font-family">sans-serif</xsl:attribute>
    <xsl:attribute name="font-weight">bold</xsl:attribute>
    <xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
    <xsl:attribute name="space-before.optimum">
      <xsl:value-of select="$sectiontopspace"/>
    </xsl:attribute>
    <xsl:attribute name="space-before.minimum">
      <xsl:value-of select="$sectiontopspace"/>
    </xsl:attribute>
    <xsl:attribute name="space-after.optimum">6pt</xsl:attribute>
    <xsl:attribute name="space-after.minimum">6pt</xsl:attribute>
    <xsl:attribute name="space-after.maximum">9pt</xsl:attribute>
    <xsl:attribute name="color">
      <xsl:value-of select="$specialfacecolor"/>
    </xsl:attribute>
  </xsl:attribute-set>
  <xsl:template name="sectionhead">
    <xsl:param name="headsize" select="'100%'"/>
    <xsl:param name="headstyle" select="'normal'"/>
    <fo:list-block
    id="{generate-id(..)}"
    margin-left="{concat('-', $headeroffset)}"
    provisional-distance-between-starts="{$headeroffset}"
    provisional-label-separation="6pt"
    font-size="{$headsize}"
    line-height="{$headsize}"
    font-style="{$headstyle}"
     xsl:use-attribute-sets="headercontrol"><xsl:attribute name="space-before">
        <xsl:choose>
          <xsl:when test="not(../preceding-sibling::*)">12pt</xsl:when>
          <xsl:otherwise>6pt</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <fo:list-item keep-with-next.within-page="always">
        <fo:list-item-label
          end-indent="label-end()">
          call-template marksectitle
        </fo:list-item-label>
        <fo:list-item-body
          start-indent="body-start()">
          <fo:block
            margin-left="{$mainindent}"
            text-indent="{$hangingindent}">
            <fo:inline font-style="normal"><xsl:if test="$secnumbers">
          <xsl:number level="multiple" format="1.1.1.1 " count="section|subsec1|subsec2|subsec3"/>
        </xsl:if></fo:inline>
            <xsl:apply-templates/>
          </fo:block>
        </fo:list-item-body>
      </fo:list-item></fo:list-block>
  </xsl:template>
  <xsl:template name="marksectitle">
    <fo:block
      text-align="end"
      font-style="normal"><xsl:choose>
        <xsl:when test="parent::section">&#xA7;</xsl:when>
        <xsl:when test="parent::subsec1"/>
        <xsl:otherwise/>
      </xsl:choose></fo:block>
  </xsl:template>
  <xsl:template match="section/title">
    <xsl:call-template name="sectionhead">
      <xsl:with-param name="headsize">125%</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="subsec1/title">
    <xsl:call-template name="sectionhead">
      <xsl:with-param name="headsize">110%</xsl:with-param>
      <xsl:with-param name="headstyle">italic</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="subsec2/title">
    <xsl:call-template name="sectionhead"/>
  </xsl:template>
  <xsl:template match="subsec3/title">
    <xsl:call-template name="sectionhead">
      <xsl:with-param name="headsize">90%</xsl:with-param>
      <xsl:with-param name="headstyle">italic</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  <xsl:attribute-set name="indentedblock">
    <xsl:attribute name="margin-left">
      <xsl:value-of select="$mainindent"/>
    </xsl:attribute>
    <xsl:attribute name="margin-right">
      <xsl:value-of select="$mainindent"/>
    </xsl:attribute>
    <xsl:attribute name="padding-start">6pt</xsl:attribute>
    <xsl:attribute name="padding-end">6pt</xsl:attribute>
    <xsl:attribute name="space-before">6pt</xsl:attribute>
    <xsl:attribute name="space-after">6pt</xsl:attribute>
  </xsl:attribute-set>
  <xsl:template match="note|lquote">
    <fo:block
    font-size="95%"
     xsl:use-attribute-sets="indentedblock">
     <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="para">
    <fo:block><xsl:attribute name="space-before">
        <xsl:choose>
          <xsl:when test="not(preceding-sibling::para)">6pt</xsl:when>
          <xsl:otherwise>6pt</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="li/para|note/para|def/para|lquote/para|figure/para|caption/para|ftnote/para">
    <fo:block text-indent="0pt"><xsl:if test="preceding-sibling::*">
        <xsl:attribute name="space-before">4pt</xsl:attribute>
      </xsl:if>
      <xsl:if test="preceding-sibling::*and not(following-sibling::*)">
        <xsl:attribute name="keep-with-previous">always</xsl:attribute>
      </xsl:if>
      <xsl:if test="parent::note and not(preceding-sibling::*)">
        <fo:inline font-style="italic"
        font-size="90%">NOTE: </fo:inline>
      </xsl:if>
      <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="randlist|seqlist">
    <fo:list-block
    margin-left="0pt"
    margin-right="{$mainindent}"
    space-before="4pt"
    space-after="4pt"
    provisional-distance-between-starts="{$extraindent}"
    provisional-label-separation="6pt">
    <xsl:apply-templates/>
  </fo:list-block>
  </xsl:template>
  <xsl:template match="li">
    <fo:list-item padding-before="4pt"><xsl:if test="not(preceding-sibling::li)">
        <xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
      </xsl:if>
      <xsl:if test="not(following-sibling::li)">
        <xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
      </xsl:if>
      <fo:list-item-label end-indent="label-end()">
      <fo:block text-align="end"><xsl:choose>
          <xsl:when test="parent::randlist">
            <xsl:choose>
              <xsl:when test="../@style='bulleted'">&#x2022;</xsl:when>
              <xsl:when test="../@style='dashed'">-</xsl:when>
              <xsl:otherwise/>
            </xsl:choose>
          </xsl:when>
          <xsl:when test="parent::seqlist">
            <xsl:choose>
              <xsl:when test="../@number='ualpha'">
                <xsl:number format="A."/>
              </xsl:when>
              <xsl:when test="../@number='uroman'">
                <xsl:number format="I."/>
              </xsl:when>
              <xsl:when test="../@number='lalpha'">
                <xsl:number format="a."/>
              </xsl:when>
              <xsl:when test="../@number='lroman'">
                <xsl:number format="i."/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:number format="1."/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise/>
        </xsl:choose></fo:block>
    </fo:list-item-label>
      <fo:list-item-body start-indent="body-start()">
      apply-templates
    </fo:list-item-body></fo:list-item>
  </xsl:template>
  <xsl:template match="sgml.block|verbatim">
    <fo:block
    white-space-collapse="false"
    linefeed-treatment="preserve"
    font-family="monospace"
    padding-before="3pt"
    padding-after="3pt"
    font-size="85%"
    line-height="100%"
     xsl:use-attribute-sets="indentedblock"><xsl:attribute name="margin-left">
        <xsl:choose>
          <xsl:when test="parent::figure">0pt</xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$mainindent"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:attribute name="margin-right">
        <xsl:choose>
          <xsl:when test="parent::figure">6pt</xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$mainindent"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:attribute name="background-color">
        <xsl:choose>
          <xsl:when test="parent::figure">
            <xsl:value-of select="$mainbgcolor"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$blockbgcolor"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="deflist/title">
    <fo:block
      margin-left="{$defoffset}"
      space-after="6pt"
       xsl:use-attribute-sets="headercontrol">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="deflist">
    <fo:block space-before="6pt">
    apply-templates with-nodes title
    <fo:list-block
      space-after="6pt"
      provisional-distance-between-starts="{$defoffset}"
      provisional-label-separation="9pt"><xsl:if test="term.heading">
        <fo:list-item
          space-before="3pt"
          font-weight="bold">
          <fo:list-item-label
            end-indent="label-end()">
            <xsl:apply-templates select="term.heading"/>
          </fo:list-item-label>
          <fo:list-item-body
            start-indent="body-start()">
            <xsl:apply-templates select="def.heading"/>
          </fo:list-item-body>
        </fo:list-item>
      </xsl:if>
      <xsl:apply-templates select="def.item"/></fo:list-block>
</fo:block>
  </xsl:template>
  <xsl:template match="def.item">
    <fo:list-item
    space-after="6pt"><xsl:if test="not(preceding-sibling::def.item)">
        <xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
      </xsl:if>
      <xsl:if test="not(following-sibling::def.item)">
        <xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates/></fo:list-item>
  </xsl:template>
  <xsl:template match="term.heading|def.term">
    <fo:list-item-label
      end-indent="label-end()">
      <fo:block text-align="end">
        <xsl:apply-templates/>
      </fo:block>
    </fo:list-item-label>
  </xsl:template>
  <xsl:template match="def.heading">
    <fo:block>
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="def">
    <fo:list-item-body
    start-indent="body-start()">
    <xsl:apply-templates/>
  </fo:list-item-body>
  </xsl:template>
  <xsl:template match="acronym">
    <fo:inline font-variant="small-caps">
    <xsl:apply-templates/>
  </fo:inline>
  </xsl:template>
  <xsl:template match="expansion"> [<xsl:apply-templates/>]</xsl:template>
  <xsl:template match="cit">
    <fo:wrapper font-style="italic">
   <xsl:apply-templates/>
 </fo:wrapper>
  </xsl:template>
  <xsl:template match="sgml">
    <fo:wrapper
    font-size="95%"
    font-family="monospace">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="highlight[@style='bold']">
    <fo:wrapper font-weight="bold" font-size="95%">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="highlight[@style='ital']">
    <fo:wrapper font-style="italic">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="highlight[@style='under']">
    <fo:wrapper text-decoration="underline">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="highlight[@style='rom']">
    <fo:wrapper font-style="normal" font-weight="normal">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="highlight[@style='bital']">
    <fo:wrapper font-style="italic" font-weight="bold">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="sub">
    <fo:wrapper font-size="60%"
    baseline-shift="sub">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="super">
    <fo:wrapper baseline-shift="25%"
             font-size="60%">
    # vertical-align maybe should be baseline-shift,
    # but FOP 0.19 doesn't do it
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="sym">
    <fo:wrapper font-family="Symbol" font-style="normal">
    <xsl:apply-templates/>
  </fo:wrapper>
  </xsl:template>
  <xsl:template match="figure">
    <fo:float float="before"
    id="{generate-id()}"
    padding-left="6pt"
    padding-top="6pt"
    padding-bottom="6pt"
    keep-together.within-page="always"
    font-size="{$smallfontsize}"
    line-height="{$smalllineheight}"
    font-family="serif"
    background-color="{$blockbgcolor}"
    space-before="6pt"
    space-after="6pt"
     xsl:use-attribute-sets="borderbefore borderafter"><xsl:apply-templates select="graphic|verbatim|para"/>
      <fo:block
      font-size="85%"
      font-weight="bold"
      space-before="6pt"
      keep-with-next.within-page="always"
       xsl:use-attribute-sets="headercontrol">Figure <xsl:number level="any"/>&#x2005;&#x2005;<xsl:apply-templates select="title"/></fo:block>
      <xsl:apply-templates select="caption"/></fo:float>
  </xsl:template>
  <xsl:template match="figure[@anchor='fixed']">
    <fo:block
    id="{generate-id()}"
    padding-left="6pt"
    padding-top="6pt"
    padding-bottom="6pt"
    keep-together.within-page="always"
    font-size="{$smallfontsize}"
    line-height="{$smalllineheight}"
    font-family="serif"
    background-color="{$blockbgcolor}"
    space-before="6pt"
    space-after="6pt"
     xsl:use-attribute-sets="borderbefore borderafter"><xsl:apply-templates select="graphic|verbatim|para"/>
      <fo:block
      font-size="85%"
      font-weight="bold"
      space-before="6pt"
      keep-with-next.within-page="always"
       xsl:use-attribute-sets="headercontrol">Figure <xsl:number level="any"/>&#x2005;&#x2005;<xsl:apply-templates select="title"/></fo:block>
      <xsl:apply-templates select="caption"/></fo:block>
  </xsl:template>
  <xsl:template match="figure/title">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="caption">
    <fo:block
    font-size="85%">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="graphic">
    <xsl:variable name="filename">
      <xsl:value-of select="unparsed-entity-uri(@figname)"/>
    </xsl:variable>
    <fo:block>
    <fo:external-graphic src="{$filename}" max-width="336pt"><xsl:for-each select="@scale">
        <xsl:attribute name="content-width">value-of .%</xsl:attribute>
      </xsl:for-each></fo:external-graphic>
  </fo:block>
  </xsl:template>
  <xsl:template match="inline.graphic">
    <xsl:variable name="filename">
      <xsl:value-of select="unparsed-entity-uri(@figname)"/>
    </xsl:variable>
    <fo:inline><fo:external-graphic src="{$filename}" background-color="white"/></fo:inline>
  </xsl:template>
  <xsl:template name="makefilename">
    <xsl:param name="filename" select="''"/>
    <xsl:value-of select="$filename"/>
    <xsl:choose>
      <xsl:when test="contains($filename,'/')"/>
      <xsl:call-template name="makefilename">
        <xsl:with-param name="filename" select="substring-after($filename,'/')"/>
      </xsl:call-template>
      <xsl:otherwise>
        <xsl:value-of select="concat('file:../graphics/',substring($filename,1,(string-length($filename)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="tabletitle">Table <xsl:number level="any"/>
    <xsl:if test="title">&#x2005;&#x2005;</xsl:if>
    <xsl:apply-templates select="title" mode="inline"/>
  </xsl:template>
  <xsl:template match="table">
    <xsl:if test="count(tgroup)>1">
      <xsl:message>Warning: table with more than one tgroup being processed as separate tables....</xsl:message>
    </xsl:if>
    <fo:block
    space-before="6pt"
    space-after="12pt"><fo:block
      font-size="85%"
      font-weight="bold"
      keep-with-next.within-page="always"
       xsl:use-attribute-sets="headercontrol"><xsl:call-template name="tabletitle"/></fo:block>
      <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="tgroup">
    <fo:table
       xsl:use-attribute-sets="borderbefore borderafter"><xsl:if test="not(colspec)">
        <xsl:call-template name="maketablecols"/>
      </xsl:if>
      <xsl:apply-templates/></fo:table>
  </xsl:template>
  <xsl:key name="colspecsbyname" match="colspec" use="concat(generate-id(ancestor::tgroup[1]),@colname)">
  <xsl:template name="maketablecols">
    <xsl:param name="tablewidth" select="5"/>
    <xsl:for-each select="tbody/row">
      <xsl:sort select="count(entry)" order="descending"/>
      <xsl:if test="position()=1">
        <xsl:variable name="colcount" select="count(entry)"/>
        <xsl:variable name="colwidth" select="concat(($tablewidth div $colcount),'in')"/>
        <xsl:for-each select="entry">
          <fo:table-column column-width="{$colwidth}"/>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  <xsl:template match="colspec">
    <fo:table-column>
    for-each @colwidth
      attribute column-width : value-of .
  </fo:table-column>
  </xsl:template>
  <xsl:template match="thead">
    <fo:table-header
    font-size="85%"
    font-weight="bold"
     xsl:use-attribute-sets="borderafter">
    <xsl:apply-templates/>
  </fo:table-header>
  </xsl:template>
  <xsl:template match="tbody">
    <fo:table-body>
    <xsl:apply-templates/>
  </fo:table-body>
  </xsl:template>
  <xsl:template match="row">
    <fo:table-row keep-together.within-page="always">
    <xsl:apply-templates/>
  </fo:table-row>
  </xsl:template>
  <xsl:template match="entry">
    <fo:table-cell
    padding-before="2pt"
    padding-after="2pt"
    padding-start="6pt"
    padding-end="6pt"><xsl:for-each select="@align">
        <xsl:attribute name="text-align">
          <xsl:choose>
            <xsl:when test=".='left'">start</xsl:when>
            <xsl:when test=".='right'">end</xsl:when>
            <xsl:when test=".='center'">center</xsl:when>
            <xsl:when test=".='justify'">justify</xsl:when>
            <xsl:otherwise>start</xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
      </xsl:for-each>
      <xsl:if test="@namest and@nameend">
        <xsl:attribute name="number-columns-spanned">
          <xsl:variable name="thistgroup" select="generate-id(ancestor::tgroup[1])"/>
          <xsl:variable name="startspec" select="key('colspecsbyname',concat($thistgroup,@namest))"/>
          <xsl:variable name="endspec" select="key('colspecsbyname',concat($thistgroup,@nameend))"/>
          <xsl:value-of select="1+(count($endspec/preceding-sibling::colspec)"/>
        </xsl:attribute>
      </xsl:if>
      <fo:block>
      <xsl:apply-templates/>
    </fo:block></fo:table-cell>
  </xsl:template>
  <xsl:key name="reftargets" match="*[@id]" use="@id">
  <xsl:key name="bibitems-by-id" match="bibitem" use="@id">
  <xsl:key name="footnotes-by-id" match="ftnote" use="@id">
  <xsl:template match="bibref">
    <fo:inline>[<xsl:value-of select="key('bibitems-by-id',@refloc)/bib"/>]</fo:inline>
  </xsl:template>
  <xsl:template match="xref">
    <xsl:apply-templates select="key('reftargets',@refloc)" mode="xreftext">
      <xsl:with-param name="type" select="@type"/>
      <xsl:with-param name="caller" select="."/>
    </xsl:apply-templates>
  </xsl:template>
  <xsl:template match="section|subsec1|subsec2|subsec3" mode="xreftext">
    <xsl:param name="type" select="false()"/>
    <xsl:param name="caller" select="."/>
    <fo:basic-link internal-destination="{generate-id()}" color="{$specialfacecolor}"><xsl:choose>
        <xsl:when test="$type='title'">&ldquo;<xsl:apply-templates select="title" mode="inline"/>&rdquo;</xsl:when>
        <xsl:otherwise>
          <xsl:number level="multiple" format="1.1.1.1" count="section|subsec1|subsec2|subsec3"/>
        </xsl:otherwise>
      </xsl:choose></fo:basic-link>
  </xsl:template>
  <xsl:template name="makerefstring">
    <xsl:param name="caller" select="."/>
  </xsl:template>
  <xsl:template match="title" mode="inline">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="figure" mode="xreftext">
    <xsl:param name="type" select="false()"/>
    <xsl:param name="caller" select="."/>
    <fo:basic-link internal-destination="{generate-id()}" color="{$specialfacecolor}"><xsl:choose>
        <xsl:when test="$type='title'">&ldquo;<xsl:value-of select="title"/>&rdquo;</xsl:when>
        <xsl:otherwise>
          <xsl:number level="any"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:call-template name="makerefstring">
        <xsl:with-param name="caller" select="$caller"/>
      </xsl:call-template></fo:basic-link>
  </xsl:template>
  <xsl:template match="ftnote">
    <xsl:variable name="noteno">
      <xsl:number level="any"/>
    </xsl:variable>
    <fo:inline baseline-shift="25%"
             font-size="60%"
             line-height="60%">
    <xsl:value-of select="$noteno"/>
  </fo:inline>
  </xsl:template>
  <xsl:template match="fnref">
    <xsl:variable name="noteno">
      <xsl:for-each select="key('footnotes-by-id',@refloc)">
        <xsl:number level="any"/>
      </xsl:for-each>
    </xsl:variable>
    <fo:inline font-size="60%"
    baseline-shift="25%">
    <xsl:value-of select="$noteno"/>
  </fo:inline>
  </xsl:template>
  <xsl:template name="footnotes">
    <xsl:if test="$footnotes">
      <fo:block
        id="footnotes"
        font-size="125%"
         xsl:use-attribute-sets="borderbefore headercontrol"
        padding-before="6pt"
        space-before.optimum="{$sectiontopspace}">
      Notes
    </fo:block>
      <fo:list-block
        margin-left="0pt"
        margin-right="{$mainindent}"
        space-before="4pt"
        space-after="4pt"
        provisional-distance-between-starts="{$extraindent}"
        provisional-label-separation="6pt">
      <xsl:apply-templates select="$footnotes" mode="notes"/>
    </fo:list-block>
    </xsl:if>
  </xsl:template>
  <xsl:template match="ftnote" mode="notes">
    <xsl:variable name="noteno">
      <xsl:number level="any" format="1."/>
    </xsl:variable>
    <fo:list-item space-after="6pt">
    <fo:list-item-label end-indent="label-end()">
      <fo:block text-align="end">
        <xsl:value-of select="$noteno"/>
      </fo:block>
    </fo:list-item-label>
    <fo:list-item-body
      start-indent="body-start()">
      <xsl:apply-templates/>
    </fo:list-item-body>
  </fo:list-item>
  </xsl:template>
  <xsl:template name="rear">
    <xsl:apply-templates select="rear"/>
    <xsl:call-template name="authorinfo"/>
    <xsl:call-template name="documentfooter"/>
  </xsl:template>
  <xsl:template match="acknowl">
    <fo:block
      id="acknowl"
      font-size="125%"
      space-before="6pt"
       xsl:use-attribute-sets="borderbefore headercontrol">
    Acknowledgements
  </fo:block>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="bibliog">
    <fo:block
      id="bibliog"
      font-size="125%"
       xsl:use-attribute-sets="borderbefore headercontrol"
      padding-before="6pt"
      space-before.optimum="{$sectiontopspace}">
    Bibliography
  </fo:block>
    <xsl:apply-templates>
      <xsl:sort select="bib"/>
    </xsl:apply-templates>
  </xsl:template>
  <xsl:template match="bibitem">
    <fo:block
    keep-together="always"
    space-before="6pt"
    margin-left="{$mainindent}"
    text-indent="{$hangingindent}"><xsl:if test="position()=1">
        <xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
      </xsl:if>
      <xsl:if test="position()=last()">
        <xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="bib">
    <fo:inline font-weight="bold">[<xsl:apply-templates/>]</fo:inline>
  </xsl:template>
  <xsl:template match="pub">
    <xsl:text> </xsl:text>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="email">
    <fo:inline font-style="italic">
    <fo:basic-link external-destination="mailto:{.}" color="{$specialfacecolor}">
      <xsl:apply-templates/>
    </fo:basic-link>
  </fo:inline>
  </xsl:template>
  <xsl:template match="web">
    <fo:inline font-weight="bold" font-size="90%">
    <fo:basic-link external-destination="{.}" color="{$specialfacecolor}">
      <xsl:apply-templates/>
    </fo:basic-link>
  </fo:inline>
  </xsl:template>
  <xsl:template name="authorinfo">
    <fo:block
      id="authors"
      font-size="125%"
       xsl:use-attribute-sets="borderbefore headercontrol"
      padding-before="6pt"
      space-before.optimum="{$sectiontopspace}">The Author<xsl:if test="count($authors)>1">s</xsl:if></fo:block>
    <xsl:apply-templates select="$authors" mode="authorinfo"/>
  </xsl:template>
  <xsl:template match="author" mode="authorinfo">
    <fo:block
      keep-together.within-page="always"
      font-size="10pt"
      font-family="sans-serif"
      line-height="11.5pt"
      padding-before="6pt"
      padding-after="6pt"><fo:block
      font-weight="bold"><xsl:apply-templates select="fname"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="surname"/></fo:block>
      <xsl:apply-templates select="jobtitle|address|bio"/></fo:block>
  </xsl:template>
  <xsl:template match="jobtitle">
    <fo:block
    font-style="italic">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="address">
    <fo:block
    font-style="italic">
    <xsl:apply-templates select="affil|subaffil"/>
  </fo:block>
    <xsl:apply-templates select="aline|city|state|province|cntry|postcode|phone|fax|email|web"/>
  </xsl:template>
  <xsl:template match="affil">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="subaffil">, <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="aline|city|cntry|province|state|postcode">
    <fo:block>
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template match="phone">
    <fo:block>tel: <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="fax">
    <fo:block>fax: <xsl:apply-templates/></fo:block>
  </xsl:template>
  <xsl:template match="address/email">
    <fo:block font-size="90%">
    <fo:basic-link external-destination="mailto:{.}" color="{$specialfacecolor}">
      <xsl:apply-templates/>
    </fo:basic-link>
  </fo:block>
  </xsl:template>
  <xsl:template match="address/web">
    <fo:block font-size="90%">
    <!-- font-weight="bold">
    <fo:basic-link external-destination="{.}" color="{$specialfacecolor}">
      <xsl:apply-templates/>
    </fo:basic-link>
  </fo:block>
  </xsl:template>
  <xsl:template match="bio">
    <fo:block
    font-family="serif">
    <xsl:apply-templates/>
  </fo:block>
  </xsl:template>
  <xsl:template name="documentfooter">
    <fo:block id="footer"
    background-color="{$blockbgcolor}"
    space-before.maximum="36pt"
    space-before.optimum="24pt"
    font-family="sans-serif"
    keep-together.within-page="always"
    keep-with-previous.within-page="always">
    <!-- Apparently gratuitous block keeps background from "spilling over" -->
    <fo:block
      padding-before="6pt"
      padding-after="6pt"
      padding-start="6pt"
      padding-end="6pt"
      text-align="center">
      <fo:block
        font-weight="bold">
        <xsl:value-of select="$conference"/>
      </fo:block>
      <fo:block
        font-size="85%"><xsl:value-of select="$venue"/>, <xsl:value-of select="$dates"/></fo:block>
      <xsl:copy-of select="$creditsblocks"/>
    </fo:block>
  </fo:block>
  </xsl:template>
</xsl:stylesheet>
